@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataSah::Coerce;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 require Data::Sah::Coerce;
 require DateTime;
@@ -46,7 +46,7 @@ Bencher::Scenario::DataSah::Coerce - Benchmark coercion
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::DataSah::Coerce (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-20.
+This document describes version 0.07 of Bencher::Scenario::DataSah::Coerce (from Perl distribution Bencher-Scenarios-DataSah), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -56,6 +56,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -80,61 +84,62 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
 
+ #table1#
  [
     200,
     "OK",
     [
        {
           "arg_data" : "2016-05-16",
-          "errors" : "2.6e-08",
-          "rate" : "5.8e+04",
-          "samples" : 21,
-          "time" : "17",
+          "errors" : "6.1e-09",
+          "rate" : "72900",
+          "samples" : 24,
+          "time" : "13.7",
           "vs_slowest" : "1"
        },
        {
           "arg_data" : 1463373166,
-          "errors" : "3.3e-09",
-          "rate" : "8.6e+05",
+          "errors" : "8.5e-10",
+          "rate" : "1600000",
           "samples" : 20,
-          "time" : "1.2",
-          "vs_slowest" : "15"
+          "time" : "0.61",
+          "vs_slowest" : "22"
        },
        {
           "arg_data" : [],
-          "errors" : "2.1e-10",
-          "rate" : "1.78e+06",
+          "errors" : "8.3e-10",
+          "rate" : "2200000",
           "samples" : 20,
-          "time" : "0.562",
-          "vs_slowest" : "30.7"
+          "time" : "0.45",
+          "vs_slowest" : "31"
        },
        {
           "arg_data" : "abc",
-          "errors" : "2.2e-10",
-          "rate" : "1.82e+06",
+          "errors" : "2.1e-10",
+          "rate" : "2540000",
           "samples" : 20,
-          "time" : "0.55",
-          "vs_slowest" : "31.3"
+          "time" : "0.394",
+          "vs_slowest" : "34.8"
        },
        {
           "arg_data" : 123,
-          "errors" : "6.2e-10",
-          "rate" : "1.8e+06",
+          "errors" : "6.5e-10",
+          "rate" : "2700000",
           "samples" : 20,
-          "time" : "0.54",
-          "vs_slowest" : "32"
+          "time" : "0.37",
+          "vs_slowest" : "37"
        },
        {
           "arg_data" : null,
-          "errors" : "1e-10",
-          "rate" : "4.05e+06",
-          "samples" : 20,
-          "time" : "0.247",
-          "vs_slowest" : "69.7"
+          "errors" : "8.1e-11",
+          "rate" : "7470000",
+          "samples" : 33,
+          "time" : "0.134",
+          "vs_slowest" : "102"
        }
     ],
     {
@@ -147,7 +152,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
        "func.cpu_info" : [
           {
              "L2_cache" : {
-                "max_cache_size" : "6144 KB"
+                "max_cache_size" : "4096 KB"
              },
              "address_width" : "64",
              "architecture" : "AMD-64",
@@ -185,6 +190,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "pbe",
                 "syscall",
                 "nx",
+                "pdpe1gb",
                 "rdtscp",
                 "lm",
                 "constant_tsc",
@@ -207,6 +213,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "est",
                 "tm2",
                 "ssse3",
+                "fma",
                 "cx16",
                 "xtpr",
                 "pdcm",
@@ -214,16 +221,20 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "sse4_1",
                 "sse4_2",
                 "x2apic",
+                "movbe",
                 "popcnt",
                 "tsc_deadline_timer",
                 "aes",
                 "xsave",
                 "avx",
+                "f16c",
+                "rdrand",
                 "lahf_lm",
+                "abm",
+                "3dnowprefetch",
                 "ida",
                 "arat",
                 "epb",
-                "xsaveopt",
                 "pln",
                 "pts",
                 "dtherm",
@@ -231,20 +242,34 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "vnmi",
                 "flexpriority",
                 "ept",
-                "vpid"
+                "vpid",
+                "fsgsbase",
+                "tsc_adjust",
+                "bmi1",
+                "hle",
+                "avx2",
+                "smep",
+                "bmi2",
+                "erms",
+                "invpcid",
+                "rtm",
+                "rdseed",
+                "adx",
+                "smap",
+                "xsaveopt"
              ],
              "manufacturer" : "GenuineIntel",
-             "model" : "42",
-             "name" : "Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz",
-             "number_of_cores" : "4",
+             "model" : "61",
+             "name" : "Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz",
+             "number_of_cores" : "2",
              "number_of_logical_processors" : 4,
              "processor_id" : "0",
-             "speed" : "3250.882",
-             "stepping" : "7"
+             "speed" : "2599.953",
+             "stepping" : "4"
           },
           {
              "L2_cache" : {
-                "max_cache_size" : "6144 KB"
+                "max_cache_size" : "4096 KB"
              },
              "address_width" : "64",
              "architecture" : "AMD-64",
@@ -282,6 +307,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "pbe",
                 "syscall",
                 "nx",
+                "pdpe1gb",
                 "rdtscp",
                 "lm",
                 "constant_tsc",
@@ -304,6 +330,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "est",
                 "tm2",
                 "ssse3",
+                "fma",
                 "cx16",
                 "xtpr",
                 "pdcm",
@@ -311,16 +338,20 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "sse4_1",
                 "sse4_2",
                 "x2apic",
+                "movbe",
                 "popcnt",
                 "tsc_deadline_timer",
                 "aes",
                 "xsave",
                 "avx",
+                "f16c",
+                "rdrand",
                 "lahf_lm",
+                "abm",
+                "3dnowprefetch",
                 "ida",
                 "arat",
                 "epb",
-                "xsaveopt",
                 "pln",
                 "pts",
                 "dtherm",
@@ -328,20 +359,34 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "vnmi",
                 "flexpriority",
                 "ept",
-                "vpid"
+                "vpid",
+                "fsgsbase",
+                "tsc_adjust",
+                "bmi1",
+                "hle",
+                "avx2",
+                "smep",
+                "bmi2",
+                "erms",
+                "invpcid",
+                "rtm",
+                "rdseed",
+                "adx",
+                "smap",
+                "xsaveopt"
              ],
              "manufacturer" : "GenuineIntel",
-             "model" : "42",
-             "name" : "Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz",
-             "number_of_cores" : "4",
+             "model" : "61",
+             "name" : "Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz",
+             "number_of_cores" : "2",
              "number_of_logical_processors" : 4,
              "processor_id" : "1",
-             "speed" : "3244.222",
-             "stepping" : "7"
+             "speed" : "2599.953",
+             "stepping" : "4"
           },
           {
              "L2_cache" : {
-                "max_cache_size" : "6144 KB"
+                "max_cache_size" : "4096 KB"
              },
              "address_width" : "64",
              "architecture" : "AMD-64",
@@ -379,6 +424,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "pbe",
                 "syscall",
                 "nx",
+                "pdpe1gb",
                 "rdtscp",
                 "lm",
                 "constant_tsc",
@@ -401,6 +447,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "est",
                 "tm2",
                 "ssse3",
+                "fma",
                 "cx16",
                 "xtpr",
                 "pdcm",
@@ -408,16 +455,20 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "sse4_1",
                 "sse4_2",
                 "x2apic",
+                "movbe",
                 "popcnt",
                 "tsc_deadline_timer",
                 "aes",
                 "xsave",
                 "avx",
+                "f16c",
+                "rdrand",
                 "lahf_lm",
+                "abm",
+                "3dnowprefetch",
                 "ida",
                 "arat",
                 "epb",
-                "xsaveopt",
                 "pln",
                 "pts",
                 "dtherm",
@@ -425,20 +476,34 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "vnmi",
                 "flexpriority",
                 "ept",
-                "vpid"
+                "vpid",
+                "fsgsbase",
+                "tsc_adjust",
+                "bmi1",
+                "hle",
+                "avx2",
+                "smep",
+                "bmi2",
+                "erms",
+                "invpcid",
+                "rtm",
+                "rdseed",
+                "adx",
+                "smap",
+                "xsaveopt"
              ],
              "manufacturer" : "GenuineIntel",
-             "model" : "42",
-             "name" : "Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz",
-             "number_of_cores" : "4",
+             "model" : "61",
+             "name" : "Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz",
+             "number_of_cores" : "2",
              "number_of_logical_processors" : 4,
              "processor_id" : "2",
-             "speed" : "3231.628",
-             "stepping" : "7"
+             "speed" : "2599.953",
+             "stepping" : "4"
           },
           {
              "L2_cache" : {
-                "max_cache_size" : "6144 KB"
+                "max_cache_size" : "4096 KB"
              },
              "address_width" : "64",
              "architecture" : "AMD-64",
@@ -476,6 +541,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "pbe",
                 "syscall",
                 "nx",
+                "pdpe1gb",
                 "rdtscp",
                 "lm",
                 "constant_tsc",
@@ -498,6 +564,7 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "est",
                 "tm2",
                 "ssse3",
+                "fma",
                 "cx16",
                 "xtpr",
                 "pdcm",
@@ -505,16 +572,20 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "sse4_1",
                 "sse4_2",
                 "x2apic",
+                "movbe",
                 "popcnt",
                 "tsc_deadline_timer",
                 "aes",
                 "xsave",
                 "avx",
+                "f16c",
+                "rdrand",
                 "lahf_lm",
+                "abm",
+                "3dnowprefetch",
                 "ida",
                 "arat",
                 "epb",
-                "xsaveopt",
                 "pln",
                 "pts",
                 "dtherm",
@@ -522,79 +593,104 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
                 "vnmi",
                 "flexpriority",
                 "ept",
-                "vpid"
+                "vpid",
+                "fsgsbase",
+                "tsc_adjust",
+                "bmi1",
+                "hle",
+                "avx2",
+                "smep",
+                "bmi2",
+                "erms",
+                "invpcid",
+                "rtm",
+                "rdseed",
+                "adx",
+                "smap",
+                "xsaveopt"
              ],
              "manufacturer" : "GenuineIntel",
-             "model" : "42",
-             "name" : "Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz",
-             "number_of_cores" : "4",
+             "model" : "61",
+             "name" : "Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz",
+             "number_of_cores" : "2",
              "number_of_logical_processors" : 4,
              "processor_id" : "3",
-             "speed" : "3143.714",
-             "stepping" : "7"
+             "speed" : "2599.953",
+             "stepping" : "4"
           }
        ],
-       "func.elapsed_time" : 0.21452808380127,
+       "func.elapsed_time" : 0.143622159957886,
        "func.module_startup" : null,
        "func.module_versions" : {
           "Bencher::Scenario::DataSah::Coerce" : null,
           "Benchmark::Dumb" : "0.10",
-          "Devel::Platform::Info" : "0.15",
+          "Devel::Platform::Info" : "0.16",
           "Sys::Info" : "0.78",
-          "Sys::Load" : "0.2",
-          "perl" : "v5.22.1"
+          "__PACKAGE__" : "1.034",
+          "perl" : "v5.24.0"
        },
        "func.note" : "Run by Pod::Weaver::Plugin::Bencher::Scenario",
+       "func.permute" : [
+          "perl",
+          [
+             "perl"
+          ],
+          "participant",
+          [
+             0
+          ],
+          "dataset",
+          [
+             0
+          ]
+       ],
        "func.platform_info" : {
           "archname" : "x86_64",
-          "codename" : "jessie",
+          "codename" : "rosa",
           "is32bit" : 0,
           "is64bit" : 1,
-          "kernel" : "linux-3.16.0-4-amd64",
+          "kernel" : "linux-3.19.0-32-generic",
           "kname" : "Linux",
-          "kvers" : "3.16.0-4-amd64",
+          "kvers" : "3.19.0-32-generic",
           "osflag" : "linux",
-          "oslabel" : "Debian",
+          "oslabel" : "LinuxMint",
           "osname" : "GNU/Linux",
-          "osvers" : "8.0",
+          "osvers" : "17.3",
           "source" : {
              "cat /etc/.issue" : "",
-             "cat /etc/issue" : "Debian GNU/Linux 8 \\n \\l",
-             "lsb_release -a" : "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-             "uname -a" : "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.7-ckt7-1 (2015-03-01) x86_64 GNU/Linux",
+             "cat /etc/issue" : "Linux Mint 17.3 Rosa \\n \\l",
+             "lsb_release -a" : "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
+             "uname -a" : "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
              "uname -m" : "x86_64",
              "uname -o" : "GNU/Linux",
-             "uname -r" : "3.16.0-4-amd64",
+             "uname -r" : "3.19.0-32-generic",
              "uname -s" : "Linux"
           }
        },
        "func.precision" : 0,
        "func.scenario_module" : "Bencher::Scenario::DataSah::Coerce",
-       "func.sysload_after" : [
-          1.69,
-          1.15,
-          0.92
+       "func.scenario_module_md5sum" : "3f81bf39184f72bb9fde60744f642c81",
+       "func.scenario_module_mtime" : 1463763168,
+       "func.scenario_module_sha1sum" : "1f2acc2c498be7556b36a8817d7345f48b0428a7",
+       "func.scenario_module_sha256sum" : "38b8f65763fe5c353d63ba08b36fd6cb9bcf32ee39a974f68f8370d4d097596a",
+       "func.time_end" : 1485329055.89202,
+       "func.time_factor" : 1000000,
+       "func.time_start" : 1485329055.7484,
+       "table.field_aligns" : [
+          "left",
+          "number",
+          "number",
+          "number",
+          "number",
+          "number"
        ],
-       "func.sysload_before" : [
-          1.69,
-          1.15,
-          0.92
-       ],
-       "func.time_end" : 1463736596.40126,
-       "func.time_start" : 1463736596.18673,
        "table.field_units" : [
-          null,
-          null,
-          null,
           null,
           "/s",
           "μs"
        ],
        "table.fields" : [
-          "participant",
-          "dataset",
           "arg_data",
-          "perl",
           "rate",
           "time",
           "vs_slowest",
@@ -604,9 +700,8 @@ Benchmark with default options (C<< bencher -m DataSah::Coerce >>):
     }
  ]
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -630,7 +725,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
