@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataSah::Startup;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark startup overhead of loading Data::Sah and generating validators',
@@ -31,7 +31,7 @@ Bencher::Scenario::DataSah::Startup - Benchmark startup overhead of loading Data
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::DataSah::Startup (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-20.
+This document describes version 0.07 of Bencher::Scenario::DataSah::Startup (from Perl distribution Bencher-Scenarios-DataSah), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -41,6 +41,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -77,25 +81,25 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DataSah::Startup >>):
 
- +---------------------+-----------+-----------+------------+---------+---------+
- | participant         | rate (/s) | time (ms) | vs_slowest | errors  | samples |
- +---------------------+-----------+-----------+------------+---------+---------+
- | genval_str_5typical | 16        | 63        | 1          | 0.00015 | 20      |
- | genval_str_date     | 16        | 61        | 1          | 0.00018 | 20      |
- | genval_str_int      | 17        | 60        | 1.1        | 0.00026 | 20      |
- | genval_bool_int     | 17        | 59        | 1.1        | 0.00017 | 20      |
- | load_dsah+get_plc   | 3e+01     | 3e+01     | 2          | 0.00034 | 21      |
- | load_dsah           | 84        | 12        | 5.3        | 5.6e-05 | 22      |
- | perl                | 2.3e+02   | 4.3       | 15         | 2.4e-05 | 20      |
- +---------------------+-----------+-----------+------------+---------+---------+
+ #table1#
+ +---------------------+-----------+-----------+------------+-----------+---------+
+ | participant         | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +---------------------+-----------+-----------+------------+-----------+---------+
+ | genval_str_5typical |        18 |      57   |        1   | 9.2e-05   |      20 |
+ | genval_str_date     |        18 |      55   |        1   | 7.8e-05   |      20 |
+ | genval_str_int      |        19 |      53   |        1.1 | 6.2e-05   |      20 |
+ | genval_bool_int     |        19 |      53   |        1.1 |   0.00012 |      20 |
+ | load_dsah+get_plc   |        35 |      29   |        2   |   3e-05   |      20 |
+ | load_dsah           |        88 |      11   |        5   | 5.1e-05   |      20 |
+ | perl                |       200 |       5.1 |       11   |   2e-05   |      20 |
+ +---------------------+-----------+-----------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -119,7 +123,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
