@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataSah::gen_coercer;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 require Data::Sah::Coerce;
 
@@ -55,7 +55,7 @@ Bencher::Scenario::DataSah::gen_coercer - Benchmark coercion
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::DataSah::gen_coercer (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-20.
+This document describes version 0.07 of Bencher::Scenario::DataSah::gen_coercer (from Perl distribution Bencher-Scenarios-DataSah), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -65,6 +65,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -93,21 +97,21 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DataSah::gen_coercer >>):
 
+ #table1#
  +-------------------------------+-----------+-----------+------------+---------+---------+
- | dataset                       | rate (/s) | time (μs) | vs_slowest | errors  | samples |
+ | dataset                       | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------------+-----------+-----------+------------+---------+---------+
- | date (coerce to DateTime)     | 4.2e+03   | 2.4e+02   | 1          | 4.3e-07 | 20      |
- | date (coerce to Time::Moment) | 4.7e+03   | 2.1e+02   | 1.1        | 2.1e-07 | 20      |
- | date (coerce to float(epoch)) | 4.8e+03   | 2.1e+02   | 1.1        | 1.2e-06 | 20      |
+ | date (coerce to DateTime)     |      3600 |       280 |        1   | 1.3e-06 |      20 |
+ | date (coerce to Time::Moment) |      4000 |       250 |        1.1 | 6.9e-07 |      20 |
+ | date (coerce to float(epoch)) |      4700 |       210 |        1.3 | 4.8e-07 |      20 |
  +-------------------------------+-----------+-----------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -131,7 +135,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
