@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataSah::normalize_schema;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 # TODO: benchmark normalize_clset
 
@@ -68,7 +68,7 @@ Bencher::Scenario::DataSah::normalize_schema - Benchmark normalizing Sah schema
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::DataSah::normalize_schema (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-20.
+This document describes version 0.07 of Bencher::Scenario::DataSah::normalize_schema (from Perl distribution Bencher-Scenarios-DataSah), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -82,6 +82,10 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -120,33 +124,34 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DataSah::normalize_schema >>):
 
+ #table1#
  +--------------+-----------+-----------+------------+---------+---------+
- | dataset      | rate (/s) | time (μs) | vs_slowest | errors  | samples |
+ | dataset      | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +--------------+-----------+-----------+------------+---------+---------+
- | array5       | 6.8e+04   | 15        | 1          | 2.7e-08 | 20      |
- | array3       | 92032     | 10.866    | 1.3515     | 1.1e-11 | 24      |
- | array1       | 1.8e+05   | 5.6       | 2.6        | 6.7e-09 | 20      |
- | str_wildcard | 3.1e+05   | 3.2       | 4.6        | 6.7e-09 | 20      |
- | str          | 4.5e+05   | 2.2       | 6.6        | 3.3e-09 | 20      |
+ | array5       |    120000 |    8.4    |     1      |   1e-08 |      20 |
+ | array3       |    160000 |    6.4    |     1.3    | 1.3e-08 |      20 |
+ | array1       |    348000 |    2.87   |     2.92   | 2.5e-09 |      20 |
+ | str_wildcard |    551990 |    1.8116 |     4.6271 | 1.2e-11 |      23 |
+ | str          |    720000 |    1.4    |     6      | 3.4e-09 |      20 |
  +--------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DataSah::normalize_schema --module-startup >>):
 
- +----------------------+-----------+------------------------+------------+---------+---------+
- | participant          | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +----------------------+-----------+------------------------+------------+---------+---------+
- | Data::Sah::Normalize | 9.1       | 4.1                    | 1          | 4.2e-05 | 21      |
- | perl -e1 (baseline)  | 5         | 0                      | 1.8        | 2.5e-05 | 20      |
- +----------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant          | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Data::Sah::Normalize | 840                          | 4                  | 20             |        10 |                      4 |          1 | 0.00034 |      20 |
+ | perl -e1 (baseline)  | 1048                         | 4                  | 20             |         6 |                      0 |          2 | 0.00013 |      20 |
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -170,7 +175,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
